/*******************************************************************************
	
		analysis_experiment.do
		2.21.2022
		Main analysis for:
		"Values and Inequality"
		Nathan Wilmers and Letian Zhang
		
 	IN:
		/data/
			prosocial_experiment.dta 
				
	OUT:

		/results/
				descriptives.tex
		
		
*******************************************************************************/
global sec1  0  // 	SECTION 1. Plot results

*-------------------------------------------------------------------------------
* PRELIMINARIES
*-------------------------------------------------------------------------------

// Set working directory
global user Nate

if "$user"=="Nate" {
	cd "/Users/wilmers/Dropbox (MIT)/stata/bg/repkit"
}

*-------------------------------------------------------------------------------
* SECTION 1. Plot results
*-------------------------------------------------------------------------------
if $sec1 {	
	
use data/prosocial_experiment.dta, clear

drop id_college id_hs
rename * mean*
gen id = _n

// Reshape
reshape long mean, i(id) j(tag) string
split tag, p("_")

gen college =1 if tag2=="college"
replace college = 0 if tag2=="hs"
gen attract = 1 if tag1=="attract"
replace attract = 2 if tag1 =="cost"

cibar mean, over(college attract) ///
ciopts(lcolor(gs0)) barcol(gs6 gs13) ///
graphopts(graphregion(color(white)) ///
legend(order(1 2) col(1) ring(0) position(2) label(1 "High School Degree") label(2 "College Degree") symxsize(8) region(color(white))) ///
ylabel(0(1)4, angle(0) grid glcolor(gs15)) ytitle("") ///
xla(1.6 "More Qualified Applicants?" 5.1 "Willing to Work for Lower Wage?")) ///
barlabel(on) blgap(.2) bargap(20) gap(130)
graph export results/bar_prosocial_p35.pdf, replace


}
