
// GSS analysis of job meaning

** GSS data available from: https://gss.norc.org/get-the-data/stata

use id wtssall educ age year sex industry reg16 rincom* incom* wrkstat hlpoths hlpsoc using "GSS7218_R2.DTA", clear

merge 1:1 id year using data/cross7218_geo.dta, keepusing(fipsstat) nogen

foreach var in hlpoths hlpsoc reg16 sex educ age {
replace `var'=. if `var'>.
}

foreach var in hlpoths hlpsoc {
	recode `var' (1 = 5) (2 = 4) (4 = 2) (5 = 1), gen(`var'r)
	drop `var'
	rename `var'r `var'
}

egen either=rowmean(hlpoths hlpsoc)
replace either=. if hlpoths==. | hlpsoc==.
drop if age==. | educ==. |  sex==. | reg16==. | hlpoths==. |  hlpsoc==. |  either==.

gen college=educ>12 
gen agesq=age^2

foreach var in hlpoths hlpsoc either {
reg `var' college [aw = wtssall] 
est store biv`var'
reghdfe `var' college age agesq sex [aw = wtssall], absorb(i.year i.reg16)
est store controls`var'
}

estadd local controls "$\times$", replace: controlshlpoths controlshlpsoc controlseither
estadd local year "$\times$", replace: controlshlpoths controlshlpsoc controlseither
estadd local reg "$\times$", replace: controlshlpoths controlshlpsoc controlseither

label variable college "College"
label variable age "Age"
label variable agesq "Age2"
label variable sex "Female"

local note="Note: Data are General Social Survey, years 1989, 1998, 2006 and 2016.  Dependent variables are importance of a job that allows someone to help other people; that is useful to society; and the average of responses to both questions.  Controls are age, age squared and female."
wordwrap "`note'", l(95)
local noteshort=r(text)
di "`noteshort'"

cd "/Users/wilmers/Dropbox (MIT)/stata/bg/"
// For paper
esttab  biveither controlseither  bivhlpsoc controlshlpsoc bivhlpoths controlshlpoths using results/prosocialgss.tex, replace ///
b(3) se(3) star obslast r2(2) label nogaps nobaselevels lines nomtitles nonotes ///
nodepvars ///
mgroups("Av. Prosocial" "Useful to Society" "Helps Others", pattern(1 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
keep(college) ///
scalar("controls Controls for worker chars" ///
"hello Fixed effects:" ///
"year \hspace{.1cm} Year" ///
"reg \hspace{.1cm} Region") ///
title("College-educated Workers Value Prosocial Job Characteristics"\label{tab:prosocialgss}) ///
addnote("`noteshort'" ///
"* p $<$ .05; ** p $<$ .01; *** p $<$ .001 (two-tailed tests)")

