# To add a new cell, type '# %%'
# To add a new markdown cell, type '# %% [markdown]'

# %%
import numpy as np
import pandas as pd
import dask.dataframe as dd
import xml.etree.ElementTree as et
import os, sys, shutil
import time
import nltk
import re, string
import glob
nltk.download('stopwords')
nltk.download('wordnet')
from nltk.corpus import stopwords
from gensim.models import Word2Vec
from nltk.stem import WordNetLemmatizer
from nltk.stem.porter import PorterStemmer
from datetime import datetime
from multiprocessing import Pool
import multiprocessing as mp
import boto3
import botocore
from pygame import mixer
# print("Number of processors: ", mp.cpu_count())
# pool = Pool(mp.cpu_count())


# %%
def clean_dash(doc):
    doc = re.sub(r'_',' ', doc)
    return doc

def clean_data(doc):

    doc = doc.lower() # make lower case
    doc = re.sub(r'[%s]' % re.escape(string.punctuation), ' ', doc) # remove punctuation 
    doc = re.sub(r'\s+',' ', doc) # change whitespaces to one space
    doc = doc.strip()
    return doc

def remove_phrase(doc, word_list):
    
    phrase_regex = re.compile('|'.join(map(re.escape, word_list)))
    doc = phrase_regex.sub('REPLACED', doc)
    return doc    
    
def keyword_count(doc, keyword_list):
    return sum([doc.count(keyword) for keyword in keyword_list])

def counting(df, word_list):
    try:
        # Mia_2 list
        df['CleanText']          = df['CleanText'].apply(lambda x: remove_phrase(x, word_list))

        df['full_list']          = df['CleanText'].apply(lambda x: keyword_count(x, full_list_list))       
        df['medium_list']        = df['CleanText'].apply(lambda x: keyword_count(x, medium_list_list))
        df['short_list']         = df['CleanText'].apply(lambda x: keyword_count(x, short_list_list))       
        df['career_meaning']     = df['CleanText'].apply(lambda x: keyword_count(x, career_meaning_list))       
        df['worklife_meaning']   = df['CleanText'].apply(lambda x: keyword_count(x, worklife_meaning_list))

        print("{}: Dataframe process: finshed keywords counting.".format(time.strftime("%H:%M:%S", time.localtime())))
        
    except Exception as e: 
        print ("{}: >>> Error occurred from dataframe cleaning csv files as below.". format(time.strftime("%H:%M:%S", time.localtime())))
        print(e)
    return df

# def keyword_counting_each(df,key_list):
#     df = df[df['CleanText'].notna()]
#     text_list = ' '.join(df['CleanText'].tolist())
#     count_list = [text_list.count(keyword) for keyword in key_list]
#     count_df = pd.DataFrame({'count': count_list})
#     return count_df

# def generating_count_df(count_df_list, keyword_list, keyword):
#     all_count_df = pd.concat(count_df_list, axis=1)
#     all_count_df['total_count'] = all_count_df.sum(axis=1)
#     all_count_df[keyword] = keyword_list
#     all_count_df[[keyword, 'total_count']].to_csv(keyword+".csv")
#     return 1


# %%

test_string ="we have mission critical and mission itself also have mission goals and mission system or other stuff."
remove_phrase(test_string, not_include_list)


# %%
mia_df = pd.read_csv('key_words.csv', index_col=0)
#os.mknod('A_read_mia_2_csv.txt')
mia_df.reset_index(inplace=True)

mia_df['not_include']       = mia_df['not_include'].astype(str)
mia_df['full_list']         = mia_df['full_list'].astype(str)
mia_df['medium_list']       = mia_df['medium_list'].astype(str)
mia_df['short_list']        = mia_df['short_list'].astype(str)
mia_df['career_meaning']    = mia_df['career_meaning'].astype(str)
mia_df['worklife_meaning']  = mia_df['worklife_meaning'].astype(str)

mia_df['not_include']       = mia_df['not_include'].apply(lambda x: clean_data(x))
mia_df['full_list']         = mia_df['full_list'].apply(lambda x: clean_data(x))
mia_df['medium_list']       = mia_df['medium_list'].apply(lambda x: clean_data(x))
mia_df['short_list']        = mia_df['short_list'].apply(lambda x: clean_data(x))
mia_df['career_meaning']    = mia_df['career_meaning'].apply(lambda x: clean_data(x))
mia_df['worklife_meaning']  = mia_df['worklife_meaning'].apply(lambda x: clean_data(x))

not_include_list            = [ x for x in mia_df['not_include'].tolist() if x!='nan']
full_list_list              = [ x for x in mia_df['full_list'].tolist() if x!='nan']
medium_list_list            = [ x for x in mia_df['medium_list'].tolist() if x!='nan']
short_list_list             = [ x for x in mia_df['short_list'].tolist() if x!='nan']
career_meaning_list         = [ x for x in mia_df['career_meaning'].tolist() if x!='nan']
worklife_meaning_list       = [ x for x in mia_df['worklife_meaning'].tolist() if x!='nan']

mia_df.head()


# %%



# %%

file_path = "/home/hongzhuoqiao/Burning_Glass/Clean_csv/"
csv_files_path = file_path + "*.csv"
csv_files = glob.glob(csv_files_path)

for file in csv_files[0:1]:

   filename = os.path.basename(file)
   new_filename = "KEY_"+ filename[-21:]
   print ("{}: Start reading csv file {} into dataframe.".format(time.strftime("%H:%M:%S", time.localtime()), filename))
   csv_df = pd.read_csv(file_path + filename, index_col=0)
   print ("{}: Fininshed reading csv file into dataframe.".format(time.strftime("%H:%M:%S", time.localtime())))
   try: 
       
       csv_df = counting(csv_df, not_include_list)
       csv_df = csv_df.drop(columns=['CleanText'])
       csv_df.to_csv(file_path+"KEY/"+new_filename)
       print("{}: Save csv_file as file {}.".format(time.strftime("%H:%M:%S", time.localtime()), new_filename)) 
       
   except Exception as e:
       print ("{}: >>> Error occurred from parrelling counting and saving files as below.".format(time.strftime("%H:%M:%S", time.localtime())))
       print(e)

   # source = file_path + filename
   # destination = file_path + "CSV_Processed/" +filename
   # dest_path = shutil.move(source, destination)
   # print ("{}: Original File moved to {}. Current loop finished".format(time.strftime("%H:%M:%S", time.localtime()), dest_path))
   

   # mixer.init()
   # mixer.music.load('eventually.mp3')
   # mixer.music.play()

print("{}: Finished all the parsing.".format(time.strftime("%H:%M:%S", time.localtime()))) 


# %%
# new cell for counting each keywords frequency
file_path = "/home/hongzhuoqiao/Burning_Glass/Word2Vec/vocab_csv/"
csv_files_path = file_path + "*.csv"
csv_files = glob.glob(csv_files_path)

supervisory_count_df_list     =[]
nonprofit_count_df_list       =[]
diversity_count_df_list       =[]
community_count_df_list       =[]
religion_count_df_list        =[]
social_meaning_count_df_list  =[]
career_meaning_count_df_list  =[]
empowerment_count_df_list     =[]
innovation_count_df_list      =[]


for file in csv_files[0:2]:

    filename = os.path.basename(file)
    print ("filename: {}".format(filename))

    print ("{}: Start reading csv file {} into dataframe.".format(time.strftime("%H:%M:%S", time.localtime()), filename))
    csv_df = pd.read_csv(file_path + filename, index_col=0)
    print ("{}: Fininshed reading csv file into dataframe.".format(time.strftime("%H:%M:%S", time.localtime())))
    try: 
        print ("{}: start counting.".format(time.strftime("%H:%M:%S", time.localtime())))

        supervisory_count_df = keyword_counting_each(csv_df,supervisory_list)
        supervisory_count_df_list.append(supervisory_count_df)
        print ("{}: supervisory counted.".format(time.strftime("%H:%M:%S", time.localtime())))
        
        nonprofit_count_df = keyword_counting_each(csv_df, nonprofit_list)
        nonprofit_count_df_list.append(nonprofit_count_df)
        print ("{}: nonprofit counted.".format(time.strftime("%H:%M:%S", time.localtime())))
        
        diversity_count_df = keyword_counting_each(csv_df, diversity_list)
        diversity_count_df_list.append(diversity_count_df)
        print ("{}: diversity counted.".format(time.strftime("%H:%M:%S", time.localtime())))

        community_count_df = keyword_counting_each(csv_df, community_list)
        community_count_df_list.append(community_count_df)
        print ("{}: community counted.".format(time.strftime("%H:%M:%S", time.localtime())))

        religion_count_df = keyword_counting_each(csv_df, religion_list)
        religion_count_df_list.append(religion_count_df)
        print ("{}: religion counted.".format(time.strftime("%H:%M:%S", time.localtime())))

        social_meaning_count_df = keyword_counting_each(csv_df, social_meaning_list)
        social_meaning_count_df_list.append(social_meaning_count_df)
        print ("{}: social_meaning counted.".format(time.strftime("%H:%M:%S", time.localtime())))

        career_meaning_count_df = keyword_counting_each(csv_df, career_meaning_list)
        career_meaning_count_df_list.append(career_meaning_count_df)
        print ("{}: career_meaning counted.".format(time.strftime("%H:%M:%S", time.localtime())))

        empowerment_count_df = keyword_counting_each(csv_df, empowerment_list)
        empowerment_count_df_list.append(empowerment_count_df)
        print ("{}: empowerment counted.".format(time.strftime("%H:%M:%S", time.localtime())))

        innovation_count_df = keyword_counting_each(csv_df,innovation_list)
        innovation_count_df_list.append(innovation_count_df)
        print ("{}: innovation counted.".format(time.strftime("%H:%M:%S", time.localtime())))

        print ("{}: {} all count df appended.".format(time.strftime("%H:%M:%S", time.localtime()), filename[-21:]))

    except Exception as e:
        print(e)

    # source = file_path + filename
    # destination = file_path + "CSV_Processed/" +filename
    # dest_path = shutil.move(source, destination)
    # print ("{}: Original File moved to {}. Current loop finished".format(time.strftime("%H:%M:%S", time.localtime()), dest_path))
    

    # mixer.init()
    # mixer.music.load('eventually.mp3')
    # mixer.music.play()


# %%
generating_count_df(supervisory_count_df_list, supervisory_list,'supervisory')
generating_count_df(nonprofit_count_df_list, nonprofit_list,'nonprofit')
generating_count_df(diversity_count_df_list, diversity_list,'diversity')
generating_count_df(community_count_df_list, community_list,'community')
generating_count_df(religion_count_df_list, religion_list,'religion')
generating_count_df(social_meaning_count_df_list, social_meaning_list,'social_meaning')
generating_count_df(career_meaning_count_df_list, career_meaning_list,'career_meaning')
generating_count_df(empowerment_count_df_list, empowerment_list,'empowerment')
generating_count_df(innovation_count_df_list, innovation_list,'innovation')


# %%
df = pd.read_csv(file_path+new_filename, index_col=0)
df.head()


# %%
csv_df.head()


# %%
csv_df['career_meaning_keyword_count'].unique()


# %%


