/*******************************************************************************
	
		robust_bg_gd.do
		3.8.2021
		Missing DV analysis for:
		"Values and Inequality" project
		Nathan Wilmers and Letian Zhang
		
 	IN:
		/data/
			BG_0719.dta
			glassdoor_pay.dta
			oes.dta

	OUT:
			
		/results/
			results/prosocialgd.tex
		
*******************************************************************************/

*-------------------------------------------------------------------------------
* PRELIMINARIES
*-------------------------------------------------------------------------------

// Set working directory

global sec1 1  // 	SECTION 1. Open GD, construct pay variable and drop everything else
global sec2 1  // 	SECTION 2. Open BG and drop data
global sec3 1  // 	SECTION 3. Match BG to glassdoor
global sec4 0  // 	SECTION 4. OES match/weight construction
global sec5 0  // 	SECTION 5. Analysis

*-------------------------------------------------------------------------------
* SECTION 1. Open GD, construct pay variable and drop everything else
*-------------------------------------------------------------------------------
if $sec1 {	

use "glassdoor_pay.dta", clear

keep industryid employername yearofsalary statename basepayamount basepayperiodcode cashbonusyearly stockbonusyearly profitsharingyearly salescommissionyearly tipsyearly occupationgroup

egen occupationid=group(occupationgroup)

// Run correspondence code
do "glassdoor_occ_ind_codes.do"

// Base pay and total pay variables
gen basepay=basepayamount if basepayperiodcode=="HOURLY"
replace basepay=basepayamount/2088 if basepayperiodcode=="ANNUAL"
replace basepay=basepayamount/173.33 if basepayperiodcode=="MONTHLY"
egen extrapayyearly=rowtotal(cashbonusyearly stockbonusyearly profitsharingyearly salescommissionyearly tipsyearly)
gen extrapayhourly=extrapayyearly/2088
gen pay=basepay+extrapayhourly

keep employername yearofsalary statename pay basepay soc naics

foreach var in pay basepay {
	rename `var' `var't
	bys employername soc statename yearofsalary: egen `var'=mean(`var't)
	drop `var't
}

replace statename="NEW YORK" if statename=="NEW YORK STATE"
replace statename="WASHINGTON" if statename=="WASHINGTON STATE"

statastates, name(statename) nogenerate

keep employername yearofsalary statename pay basepay soc naics state_fips

drop if employername=="" | naics=="" | soc=="" | employername=="NA"
rename employername employer

// Clean employer name
replace employer=upper(employer)

// Remove weird characters
foreach char in $ & - ' / . : , # ) ( | {
	replace employer=subinstr(employer,"`char'","",.)
}

// Remove very common terms
replace employer = " " + employer + " "
replace employer = subinstr(employer," UNITED STATES OF AMERICA ","USA",.)

foreach char in LLC CENTER GROUP ASSOCIATES ASSOC INC CO LIMITED LTD LP COMPANY CORPORATION CORP  OF THE AND FOR AT SERVICES INCORPORATED ENTERPRISES USA SOLUTIONS SA INDUSTRIES PLC INTERNATIONAL {
	replace employer = subinstr(employer," `char' "," ",.)
}
replace employer=itrim(trim(employer))

gen employer_nospace=subinstr(employer," ","",.)
gen emp3=regexs(0) if regexm(employer_nospace, "^[A-Z0-9][A-Z0-9][A-Z0-9]")
replace emp3=regexs(0) if regexm(employer_nospace, "^[A-Z0-9][A-Z0-9]") & emp3==""
count if emp3==""

gen emp4=regexs(0) if regexm(employer_nospace, "^[A-Z0-9][A-Z0-9][A-Z0-9][A-Z0-9]")
replace emp4=regexs(0) if regexm(employer_nospace, "^[A-Z0-9][A-Z0-9][A-Z0-9]") & emp4==""
replace emp4=regexs(0) if regexm(employer_nospace, "^[A-Z0-9][A-Z0-9]") & emp4==""
count if emp4==""

gen emp5=regexs(0) if regexm(employer_nospace, "^[A-Z0-9][A-Z0-9][A-Z0-9][A-Z0-9][A-Z0-9]")
replace emp5=regexs(0) if regexm(employer_nospace, "^[A-Z0-9][A-Z0-9][A-Z0-9][A-Z0-9]") & emp5==""
replace emp5=regexs(0) if regexm(employer_nospace, "^[A-Z0-9][A-Z0-9][A-Z0-9]") & emp5==""
replace emp5=regexs(0) if regexm(employer_nospace, "^[A-Z0-9][A-Z0-9]") & emp5==""
count if emp5==""

// Make key variables numeric
replace soc=subinstr(soc, "-", "", .)
destring soc, replace
destring naics, replace
rename state_fips fips
gen naics2=floor(naics/100)

replace naics2=48 if naics2==49
replace naics2=31 if naics2==32 | naics2==33
replace naics2=44 if naics2==45
/*
bys emp4 soc fips naics2 yearofsalary: gen dup=_n
keep if dup==1
drop dup
*/
compress
drop statename
rename yearofsalary year

save data/gd_clean.dta, replace

}
*-------------------------------------------------------------------------------
* SECTION 2. Open BG and drop data
*-------------------------------------------------------------------------------
if $sec2 {	
// Open data
use edu prosocial_medium sector2 naics4 soc fips minsalary maxsalary exp bgtjobid year college pay_reporter bonus parttime lnskill_count exp msa logtext_length if edu!=0 using data/BG_selection_data.dta, clear

rename logtext_length lntext

// Drop postings with no education specified (as we do this in the main analysis)
drop if edu==0
drop if naics4==-999 | soc==. | lnskill_count==.

// Match in employer names
di _N
merge 1:1 bgtjobid using data/full_employers.dta, keep(3)
di _N

// Drop more postings
drop if employer=="na"

save data/bg_temp.dta, replace

use data/bg_temp.dta, clear

// Clean employer name
replace employer=upper(employer)

// Remove weird characters
foreach char in $ & - ' / . : , # ) ( | {
	replace employer=subinstr(employer,"`char'","",.)
}

// Remove very common terms
replace employer = " " + employer + " "
replace employer = subinstr(employer," UNITED STATES OF AMERICA ","USA",.)

foreach char in LLC CENTER GROUP ASSOCIATES ASSOC INC CO LIMITED LTD LP COMPANY CORPORATION CORP  OF THE AND FOR AT SERVICES INCORPORATED ENTERPRISES USA SOLUTIONS SA INDUSTRIES PLC INTERNATIONAL {
	replace employer = subinstr(employer," `char' "," ",.)
}
replace employer=itrim(trim(employer))

gen employer_nospace=subinstr(employer," ","",.)
gen emp5=regexs(0) if regexm(employer_nospace, "^[A-Z0-9][A-Z0-9][A-Z0-9][A-Z0-9][A-Z0-9]")
replace emp5=regexs(0) if regexm(employer_nospace, "^[A-Z0-9][A-Z0-9][A-Z0-9][A-Z0-9]") & emp5==""
replace emp5=regexs(0) if regexm(employer_nospace, "^[A-Z0-9][A-Z0-9][A-Z0-9]") & emp5==""
replace emp5=regexs(0) if regexm(employer_nospace, "^[A-Z0-9][A-Z0-9]") & emp5==""
count if emp5==""

// Make key variables numeric
decode soc, gen(socst)
drop soc
rename socst soc
replace soc=subinstr(soc, "-", "", .)
destring soc, replace
rename naics4 naics
destring naics, replace
replace fips=floor(fips/1000)

decode sector2, gen(naics2)
drop sector2
replace naics2=subinstr(naics2, "48-49", "48", .)
replace naics2=subinstr(naics2, "31-33", "31", .)
replace naics2=subinstr(naics2, "44-45", "44", .)
destring naics2, replace

drop _merge employer_nospace 

// Make salary variable
foreach var in min max {
	replace `var'salary=. if `var'salary==0
}
egen salary=rowmean(minsalary maxsalary)
gen lnbg_salary=ln(salary)
drop minsalary maxsalary salary

compress
sort emp5 soc naics2 fips year

save data/bg_merge_to_gd.dta, replace

use data/bg_merge_to_gd.dta, clear

gen emp3=regexs(1) if regexm(emp5, "^([A-Z0-9][A-Z0-9][A-Z0-9])+")

// Collapse observations
set seed 906
gen random=runiform()
sort emp3 soc naics2 fips year random
by emp3 soc naics2 fips year: gen dup=_n
keep if dup==1
/*
}
*/
*-------------------------------------------------------------------------------
* SECTION 3. Match BG to glassdoor
*-------------------------------------------------------------------------------
if $sec3 {	

merge 1:m emp3 soc naics2 fips year using data/gd_clean.dta, nogen keep(3)

gen naics3=floor(naics/10)
gen anysocial=prosocial_medium>1 & prosocial_medium!=.
gen lngd_pay=ln(pay)
gen lngd_basepay=ln(basepay)
drop if msa==-999

merge m:1 bgtjobid using data/skillcombo_gd.dta, nogen keep(3)

corr  lnbg_salary lngd_pay lngd_basepay

}
*-------------------------------------------------------------------------------
* SECTION 4. OES match/weight construction
*-------------------------------------------------------------------------------
if $sec4 {	

rename naics2 sector
gen soc_short=floor(soc/10000)
rename fips state

// Merge with OES
merge m:1 soc_short sector state using data/oes.dta, nogen keep(1 3)
*, nogen keep(3)

bys soc_short sector: egen oes_emp_shareoi=mean(oes_emp_share)
replace oes_emp_share=oes_emp_shareoi if oes_emp_share==.

bys soc_short state: egen oes_emp_shareos=mean(oes_emp_share)
replace oes_emp_share=oes_emp_shareos if oes_emp_share==.

bys soc_short: egen oes_emp_shareo=mean(oes_emp_share)
replace oes_emp_share=oes_emp_shareo if oes_emp_share==.

bys state: egen oes_emp_shares=mean(oes_emp_share)
replace oes_emp_share=oes_emp_shares if oes_emp_share==.

bys sector: egen oes_emp_sharei=mean(oes_emp_share)
replace oes_emp_share=oes_emp_sharei if oes_emp_share==.

egen oes_emp_sharea=mean(oes_emp_share)
replace oes_emp_share=oes_emp_sharea if oes_emp_share==.

drop oes_emp_shareoi oes_emp_shareos oes_emp_shareo oes_emp_shares oes_emp_sharei oes_emp_sharea

bys soc_short sector state year: gen bg_weight=1/_N 
gen weight = bg_weight * oes_emp_share
}
*-------------------------------------------------------------------------------
* SECTION 5. Analysis
*-------------------------------------------------------------------------------
if $sec5 {	

egen socgroup=group(soc)

local cluster i.naics3
local predbase i.college lntext lnskill_count exp bonus parttime
local pred i.anysocial##i.college lntext lnskill_count exp bonus parttime
local lm i.year#i.msa#i.naics3
local occ socgroup
local dv lngd_pay

reghdfe `dv' `predbase' [aw = weight], absorb(i.year) cluster(`cluster')
est store base
reghdfe `dv' `pred' [aw = weight], absorb(i.year) cluster(`cluster')
est store first
reghdfe `dv' `pred' [aw = weight], absorb(`lm') cluster(`cluster')
est store lm
reghdfe `dv' `pred' [aw = weight], absorb(`lm' i.`occ') cluster(`cluster')
est store occ
reghdfe `dv' `pred' [aw = weight], absorb(`lm' i.`occ'#i.skillcombo) cluster(`cluster')
est store skillint

estadd local year  "$\times$", replace: base first
estadd local lm "$\times$", replace: lm occ skillint
estadd local occ "$\times$", replace: occ
estadd local skill "$\times$", replace: skillint
estadd local controls "$\times$", replace: base first lm occ skillint

label var anysocial "Pro-social"
label var lntext "log(Text Length)"
label var college "College"
label var lnskill_count "log(Number of Skills Listed)"
label var exp "Experience Required"
label var bonus "Bonus or commission"
label var parttime "Part-time"

label define anysocial 1 "Pro-social", replace
label values anysocial anysocial

label define college 1 "College", replace
label values college college

local note="Note: Job postings are Burning Glass; dependent variable pay is from Glassdoor online reviews.  All matched postings with non-missing salary, industry and education information included.  Controls are log(text length), experience required, bonus paid and part-time job. Standard errors are clustered at the 3-digit industry level."
wordwrap "`note'", l(80)
local noteshort=r(text)
di "`noteshort'"

// For paper
esttab base first lm occ skillint using results/prosocialgd.tex, replace ///
b(3) se(3) star obslast r2(2) label nogaps nobaselevels lines nomtitles nonotes ///
nodepvars noomitted interaction(" * ") ///
keep(*1.anysocial* *1.college*) ///
scalar("controls Controls" ///
"hello Fixed effects:" ///
"year \hspace{.1cm} Year" ///
"lm \hspace{.1cm} Year X Ind. X MSA" ///
"occ \hspace{.1cm} Occup." ///
"skill \hspace{.1cm} Occup. X Skill set") ///
title("Pro-social Jobs Earning Penalty (Glassdoor-based Pay Data)"\label{tab:prosocialgd}) ///
addnote("`noteshort'" ///
"* p $<$ .05; ** p $<$ .01; *** p $<$ .001 (two-tailed tests)")

}


